@@ -5,7 +5,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2009 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2011 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -27,7 +27,7 @@
  *   nmap-os-db or nmap-service-probes.                                    *
  * o Executes Nmap and parses the results (as opposed to typical shell or  *
  *   execution-menu apps, which simply display raw Nmap output and so are  *
- *   not derivative works.)                                                * 
+ *   not derivative works.)                                                *
  * o Integrates/includes/aggregates Nmap into a proprietary executable     *
  *   installer, such as those produced by InstallShield.                   *
  * o Links to a library or executes a program that does any of the above   *
@@ -50,8 +50,8 @@
  * As a special exception to the GPL terms, Insecure.Com LLC grants        *
  * permission to link the code of this program with any version of the     *
  * OpenSSL library which is distributed under a license identical to that  *
- * listed in the included COPYING.OpenSSL file, and distribute linked      *
- * combinations including the two. You must obey the GNU GPL in all        *
+ * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
+ * linked combinations including the two. You must obey the GNU GPL in all *
  * respects for all of the code used other than OpenSSL.  If you modify    *
  * this file, you may extend this exception to your version of the file,   *
  * but you are not obligated to do so.                                     *
@@ -88,7 +88,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: strcasecmp.c 12956 2009-04-15 00:37:23Z fyodor $ */
+/* $Id: strcasecmp.c 21905 2011-01-21 00:04:51Z fyodor $ */
 
 #if !defined(HAVE_STRCASECMP) || !defined(HAVE_STRNCASECMP)
 #include <stdlib.h>
@@ -106,9 +106,9 @@ int strcasecmp(const char *s1, const char *s2)
 	cp2 = safe_malloc(strlen(s2) + 1);
 
 	for (i = 0; i < strlen(s1) + 1; i++)
-		cp1[i] = tolower(s1[i]);
+		cp1[i] = tolower((int) (unsigned char) s1[i]);
 	for (i = 0; i < strlen(s2) + 1; i++)
-		cp2[i] = tolower(s2[i]);
+		cp2[i] = tolower((int) (unsigned char) s2[i]);
   
 	ret = strcmp(cp1, cp2);
   
@@ -129,9 +129,9 @@ int strncasecmp(const char *s1, const char *s2, size_t n)
 	cp2 = safe_malloc(strlen(s2) + 1);
 
 	for (i = 0; i < strlen(s1) + 1; i++)
-		cp1[i] = tolower(s1[i]);
+		cp1[i] = tolower((int) (unsigned char) s1[i]);
 	for (i = 0; i < strlen(s2) + 1; i++)
-		cp2[i] = tolower(s2[i]);
+		cp2[i] = tolower((int) (unsigned char) s2[i]);
   
 	ret = strncmp(cp1, cp2, n);
   
